@@ -23,6 +23,7 @@
 #include "config.h"
 
 #include "bacon-video-widget-gst-missing-plugins.h"
+#include <gst/gst.h> /* for gst_registry_update and functions in bacon_video_widget_gst_missing_plugins_blacklist */
 
 #ifdef ENABLE_MISSING_PLUGIN_INSTALLATION
 
@@ -31,8 +32,6 @@
 #include <gst/pbutils/pbutils.h>
 #include <gst/pbutils/install-plugins.h>
 
-#include <gst/gst.h> /* for gst_registry_update */
-
 #include <gtk/gtk.h>
 
 #ifdef GDK_WINDOWING_X11
@@ -72,7 +71,7 @@ bacon_video_widget_gtk_plug_get_toplevel (GtkPlug *plug)
 	do
 	{
 		/* FIXME: multi-head */
-		if (XQueryTree (GDK_DISPLAY (), xid, &root,
+		if (XQueryTree (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), xid, &root,
 					&parent, &children, &nchildren) == 0)
 		{
 			g_warning ("Couldn't find window manager window");
@@ -99,7 +98,7 @@ bacon_video_widget_gst_get_toplevel (GtkWidget *widget)
 	if (GTK_IS_PLUG (parent))
 		return bacon_video_widget_gtk_plug_get_toplevel (GTK_PLUG (parent));
 	else
-		return GDK_WINDOW_XID(parent->window);
+		return GDK_WINDOW_XID(gtk_widget_get_window (parent));
 }
 #endif
 
@@ -273,7 +272,7 @@ bacon_video_widget_gst_on_missing_plugins_event (BaconVideoWidget *bvw, char **d
 	install_ctx = gst_install_plugins_context_new ();
 
 #ifdef GDK_WINDOWING_X11
-	if (GTK_WIDGET (bvw)->window != NULL && GTK_WIDGET_REALIZED (bvw))
+	if (gtk_widget_get_window (GTK_WIDGET (bvw)) != NULL && gtk_widget_get_realized (GTK_WIDGET (bvw)))
 	{
 		gulong xid = 0;
 
