@@ -56,7 +56,7 @@ typedef struct {
 GType totem_screenshot_plugin_get_type (void) G_GNUC_CONST;
 G_MODULE_EXPORT GType register_totem_plugin (GTypeModule *module);
 
-gchar *totem_screenshot_plugin_setup_file_chooser (const char *filename_format) G_GNUC_WARN_UNUSED_RESULT;
+gchar *totem_screenshot_plugin_setup_file_chooser (const char *filename_format, const char *movie_name) G_GNUC_WARN_UNUSED_RESULT;
 void totem_screenshot_plugin_update_file_chooser (const char *filename);
 
 G_END_DECLS
