@@ -681,7 +681,7 @@ totem_plugins_engine_configure_plugin (TotemPluginInfo *info,
 	gtk_window_set_transient_for (GTK_WINDOW (conf_dlg),
 				      parent);
 
-	wg = parent->group;
+	wg = gtk_window_get_group (parent);
 	if (wg == NULL)
 	{
 		wg = gtk_window_group_new ();
